@@ -1,19 +1,21 @@
 use super::*;
 use alloc::{string::String, vec::Vec};
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct ContractAbi {
     pub build_info: BuildInfoAbi,
     pub docs: &'static [&'static str],
     pub name: &'static str,
     pub constructor: Option<EndpointAbi>,
     pub endpoints: Vec<EndpointAbi>,
+    pub has_callback: bool,
     pub type_descriptions: TypeDescriptionContainerImpl,
 }
 
 impl ContractAbi {
     pub fn coalesce(&mut self, other: Self) {
         self.endpoints.extend_from_slice(other.endpoints.as_slice());
+        self.has_callback |= other.has_callback;
         self.type_descriptions.insert_all(&other.type_descriptions);
     }
 
