@@ -2,8 +2,10 @@ mod big_int_api;
 mod elliptic_curve_api;
 mod managed_buffer_api;
 mod managed_type_api;
+mod static_buffer_api;
 
 pub use big_int_api::*;
 pub use elliptic_curve_api::*;
 pub use managed_buffer_api::*;
 pub use managed_type_api::*;
+pub use static_buffer_api::*;
