@@ -7,6 +7,7 @@ mod endpoint_finish_api;
 mod error_api;
 mod log_api;
 mod managed_types;
+mod print_api;
 mod send_api;
 mod storage_api;
 pub mod uncallable;
@@ -21,6 +22,7 @@ pub use endpoint_finish_api::EndpointFinishApi;
 pub use error_api::ErrorApi;
 pub use log_api::LogApi;
 pub use managed_types::*;
+pub use print_api::PrintApi;
 pub use send_api::SendApi;
 pub use storage_api::*;
 pub use vm_api::VMApi;
