@@ -1,11 +1,11 @@
-use crate::abi::{TypeAbi, TypeDescriptionContainer};
-use crate::io::{ArgId, ContractCallArg, DynArg, DynArgInput};
-use crate::types::{ArgBuffer, SCError};
-use crate::{api::EndpointFinishApi, EndpointResult};
-use alloc::string::String;
-use alloc::vec::Vec;
+use crate::{
+    abi::{TypeAbi, TypeDescriptionContainer},
+    api::{EndpointFinishApi, ManagedTypeApi},
+    io::{ArgId, ContractCallArg, DynArg, DynArgInput},
+    DynArgOutput, EndpointResult,
+};
+use alloc::{string::String, vec::Vec};
 use core::iter::FromIterator;
-use elrond_codec::TopDecodeInput;
 
 /// Structure that allows taking a variable number of arguments
 /// or returning a variable number of results in a smart contract endpoint.
@@ -84,11 +84,7 @@ where
     T: DynArg,
 {
     // #[inline(never)]
-    fn dyn_load<I, D>(loader: &mut D, arg_id: ArgId) -> Self
-    where
-        I: TopDecodeInput,
-        D: DynArgInput<I>,
-    {
+    fn dyn_load<I: DynArgInput>(loader: &mut I, arg_id: ArgId) -> Self {
         let mut result_vec: Vec<T> = Vec::new();
         while loader.has_next() {
             result_vec.push(T::dyn_load(loader, arg_id));
@@ -106,7 +102,7 @@ where
     #[inline]
     fn finish<FA>(&self, api: FA)
     where
-        FA: EndpointFinishApi + Clone + 'static,
+        FA: ManagedTypeApi + EndpointFinishApi + Clone + 'static,
     {
         for elem in self.0.iter() {
             elem.finish(api.clone());
@@ -118,11 +114,10 @@ impl<T> ContractCallArg for &MultiArgVec<T>
 where
     T: ContractCallArg,
 {
-    fn push_async_arg(&self, serializer: &mut ArgBuffer) -> Result<(), SCError> {
+    fn push_dyn_arg<O: DynArgOutput>(&self, output: &mut O) {
         for elem in self.0.iter() {
-            elem.push_async_arg(serializer)?;
+            elem.push_dyn_arg(output);
         }
-        Ok(())
     }
 }
 
@@ -130,8 +125,8 @@ impl<T> ContractCallArg for MultiArgVec<T>
 where
     T: ContractCallArg,
 {
-    fn push_async_arg(&self, serializer: &mut ArgBuffer) -> Result<(), SCError> {
-        (&self).push_async_arg(serializer)
+    fn push_dyn_arg<O: DynArgOutput>(&self, output: &mut O) {
+        (&self).push_dyn_arg(output)
     }
 }
 
