@@ -4,6 +4,7 @@ mod interaction;
 mod io;
 mod managed;
 mod managed_codec;
+mod static_buffer;
 
 pub use super::{Box, Vec};
 pub use crypto::*;
@@ -12,3 +13,4 @@ pub use interaction::*;
 pub use io::*;
 pub use managed::*;
 pub use managed_codec::*;
+pub use static_buffer::*;
